@@ -32,7 +32,7 @@ class BufferAllocator
 	/// BufferAllocator has been specified.
 {
 public:
-	typedef ch char_type;
+	using char_type = ch;
 
 	static char_type* allocate(std::streamsize size)
 	{
