@@ -21,7 +21,6 @@
 #include "Poco/Data/ODBC/ODBC.h"
 #include "Poco/Data/ODBC/Preparator.h"
 #include "Poco/Data/ODBC/ODBCMetaColumn.h"
-#include "Poco/Data/ODBC/Error.h"
 #include "Poco/Data/ODBC/Utility.h"
 #include "Poco/Data/AbstractExtractor.h"
 #include "Poco/Data/Constants.h"
@@ -34,10 +33,10 @@
 #include "Poco/UTFString.h"
 #include "Poco/TextEncoding.h"
 #include "Poco/Exception.h"
-#include <map>
 #ifdef POCO_OS_FAMILY_WINDOWS
 	#include <windows.h>
 #endif
+
 #include <sqltypes.h>
 
 
@@ -59,7 +58,7 @@ public:
 		Poco::TextEncoding::Ptr pToEncoding = nullptr);
 		/// Creates the Extractor.
 
-	~Extractor();
+	~Extractor() override;
 		/// Destroys the Extractor.
 
 	bool extract(std::size_t pos, Poco::Int8& val) override;
