@@ -30,15 +30,15 @@ class Foundation_API Latin1Encoding: public TextEncoding
 {
 public:
 	Latin1Encoding();
-	~Latin1Encoding();
-	const char* canonicalName() const;
-	bool isA(const std::string& encodingName) const;
-	const CharacterMap& characterMap() const;
-	int convert(const unsigned char* bytes) const;
-	int convert(int ch, unsigned char* bytes, int length) const;
-	int queryConvert(const unsigned char* bytes, int length) const;
-	int sequenceLength(const unsigned char* bytes, int length) const;
-	
+	~Latin1Encoding() override;
+	const char* canonicalName() const override;
+	bool isA(const std::string& encodingName) const override;
+	const CharacterMap& characterMap() const override;
+	int convert(const unsigned char* bytes) const override;
+	int convert(int ch, unsigned char* bytes, int length) const override;
+	int queryConvert(const unsigned char* bytes, int length) const override;
+	int sequenceLength(const unsigned char* bytes, int length) const override;
+
 private:
 	static const char* _names[];
 	static const CharacterMap _charMap;
