@@ -116,17 +116,22 @@ public:
 		///   - debug
 		///   - trace
 
-	void setProperty(const std::string& name, const std::string& value);
+	void setProperty(const std::string &name, const std::string &value) override;
 		/// Sets or changes a configuration property.
 		///
 		/// Only the "channel" and "level" properties are supported, which allow
 		/// setting the target channel and log level, respectively, via the LoggingRegistry.
 		/// The "channel" and "level" properties are set-only.
 
-	void log(const Message& msg);
+	void log(const Message& msg) override;
 		/// Logs the given message if its priority is
 		/// greater than or equal to the Logger's log level.
 
+	void log(Message&& msg) override;
+		/// Logs the given message if its priority is
+		/// greater than or equal to the Logger's log level.
+		/// The message is moved to avoid copying.
+
 	void log(const Exception& exc);
 		/// Logs the given exception with priority PRIO_ERROR.
 
@@ -456,14 +461,17 @@ public:
 	static const std::string ROOT; /// The name of the root logger ("").
 
 protected:
-	typedef std::map<std::string, Ptr> LoggerMap;
+	using LoggerMap = std::map<std::string, Ptr>;
 
 	Logger(const std::string& name, Channel::Ptr pChannel, int level);
-	~Logger();
+	~Logger() override;
 
 	void log(const std::string& text, Message::Priority prio);
+	void log(std::string&& text, Message::Priority prio);
 	void logNPC(const std::string& text, Message::Priority prio);
+	void logNPC(std::string&& text, Message::Priority prio);
 	void log(const std::string& text, Message::Priority prio, const char* file, LineNumber line);
+	void log(std::string&& text, Message::Priority prio, const char* file, LineNumber line);
 
 	static std::string format(const std::string& fmt, int argc, std::string argv[]);
 	static Logger& parent(const std::string& name);
@@ -471,13 +479,17 @@ protected:
 	static Ptr find(const std::string& name);
 
 private:
-	typedef std::unique_ptr<LoggerMap> LoggerMapPtr;
+	using LoggerMapPtr = std::unique_ptr<LoggerMap>;
 
 	Logger();
 	Logger(const Logger&);
 	Logger& operator = (const Logger&);
 
+	template <typename M>
+	void logImpl(M&& msg);
+
 	void logAlways(const std::string& text, Message::Priority prio);
+	void logAlways(std::string&& text, Message::Priority prio);
 
 	std::string _name;
 	Channel::Ptr _pChannel;
@@ -515,254 +527,176 @@ private:
 	if ((logger).fatal()) (logger).fatal(msg, __FILE__, __LINE__); \
 	POCO_AMBIGUOUS_ELSE_BLOCKER_END
 
-#define poco_fatal_f1(logger, fmt, arg1) \
-	POCO_AMBIGUOUS_ELSE_BLOCKER_BEG \
-	if ((logger).fatal()) (logger).fatal(Poco::format((fmt), arg1), __FILE__, __LINE__); \
-	POCO_AMBIGUOUS_ELSE_BLOCKER_END
-
-#define poco_fatal_f2(logger, fmt, arg1, arg2) \
-	POCO_AMBIGUOUS_ELSE_BLOCKER_BEG \
-	if ((logger).fatal()) (logger).fatal(Poco::format((fmt), (arg1), (arg2)), __FILE__, __LINE__); \
-	POCO_AMBIGUOUS_ELSE_BLOCKER_END
-
-#define poco_fatal_f3(logger, fmt, arg1, arg2, arg3) \
-	POCO_AMBIGUOUS_ELSE_BLOCKER_BEG \
-	if ((logger).fatal()) (logger).fatal(Poco::format((fmt), (arg1), (arg2), (arg3)), __FILE__, __LINE__); \
-	POCO_AMBIGUOUS_ELSE_BLOCKER_END
-
-#define poco_fatal_f4(logger, fmt, arg1, arg2, arg3, arg4) \
-	POCO_AMBIGUOUS_ELSE_BLOCKER_BEG \
-	if ((logger).fatal()) (logger).fatal(Poco::format((fmt), (arg1), (arg2), (arg3), (arg4)), __FILE__, __LINE__); \
-	POCO_AMBIGUOUS_ELSE_BLOCKER_END
-
 #define poco_fatal_f(logger, fmt, ...) \
 	POCO_AMBIGUOUS_ELSE_BLOCKER_BEG \
 	if ((logger).fatal()) (logger).fatal(Poco::format((fmt), __VA_ARGS__), __FILE__, __LINE__); \
 	POCO_AMBIGUOUS_ELSE_BLOCKER_END
 
+// Deprecated: use poco_fatal_f instead
+#define poco_fatal_f1(logger, fmt, arg1) \
+	poco_fatal_f(logger, fmt, arg1)
+#define poco_fatal_f2(logger, fmt, arg1, arg2) \
+	poco_fatal_f(logger, fmt, arg1, arg2)
+#define poco_fatal_f3(logger, fmt, arg1, arg2, arg3) \
+	poco_fatal_f(logger, fmt, arg1, arg2, arg3)
+#define poco_fatal_f4(logger, fmt, arg1, arg2, arg3, arg4) \
+	poco_fatal_f(logger, fmt, arg1, arg2, arg3, arg4)
+
 #define poco_critical(logger, msg) \
 	POCO_AMBIGUOUS_ELSE_BLOCKER_BEG \
 	if ((logger).critical()) (logger).critical(msg, __FILE__, __LINE__); \
 	POCO_AMBIGUOUS_ELSE_BLOCKER_END
 
-#define poco_critical_f1(logger, fmt, arg1) \
-	POCO_AMBIGUOUS_ELSE_BLOCKER_BEG \
-	if ((logger).critical()) (logger).critical(Poco::format((fmt), (arg1)), __FILE__, __LINE__); \
-	POCO_AMBIGUOUS_ELSE_BLOCKER_END
-
-#define poco_critical_f2(logger, fmt, arg1, arg2) \
-	POCO_AMBIGUOUS_ELSE_BLOCKER_BEG \
-	if ((logger).critical()) (logger).critical(Poco::format((fmt), (arg1), (arg2)), __FILE__, __LINE__); \
-	POCO_AMBIGUOUS_ELSE_BLOCKER_END
-
-#define poco_critical_f3(logger, fmt, arg1, arg2, arg3) \
-	POCO_AMBIGUOUS_ELSE_BLOCKER_BEG \
-	if ((logger).critical()) (logger).critical(Poco::format((fmt), (arg1), (arg2), (arg3)), __FILE__, __LINE__); \
-	POCO_AMBIGUOUS_ELSE_BLOCKER_END
-
-#define poco_critical_f4(logger, fmt, arg1, arg2, arg3, arg4) \
-	POCO_AMBIGUOUS_ELSE_BLOCKER_BEG \
-	if ((logger).critical()) (logger).critical(Poco::format((fmt), (arg1), (arg2), (arg3), (arg4)), __FILE__, __LINE__); \
-	POCO_AMBIGUOUS_ELSE_BLOCKER_END
-
 #define poco_critical_f(logger, fmt, ...) \
 	POCO_AMBIGUOUS_ELSE_BLOCKER_BEG \
 	if ((logger).critical()) (logger).critical(Poco::format((fmt), __VA_ARGS__), __FILE__, __LINE__); \
 	POCO_AMBIGUOUS_ELSE_BLOCKER_END
 
+// Deprecated: use poco_critical_f instead
+#define poco_critical_f1(logger, fmt, arg1) \
+	poco_critical_f(logger, fmt, arg1)
+#define poco_critical_f2(logger, fmt, arg1, arg2) \
+	poco_critical_f(logger, fmt, arg1, arg2)
+#define poco_critical_f3(logger, fmt, arg1, arg2, arg3) \
+	poco_critical_f(logger, fmt, arg1, arg2, arg3)
+#define poco_critical_f4(logger, fmt, arg1, arg2, arg3, arg4) \
+	poco_critical_f(logger, fmt, arg1, arg2, arg3, arg4)
+
 #define poco_error(logger, msg) \
 	POCO_AMBIGUOUS_ELSE_BLOCKER_BEG \
 	if ((logger).error()) (logger).error(msg, __FILE__, __LINE__); \
 	POCO_AMBIGUOUS_ELSE_BLOCKER_END
 
-#define poco_error_f1(logger, fmt, arg1) \
-	POCO_AMBIGUOUS_ELSE_BLOCKER_BEG \
-	if ((logger).error()) (logger).error(Poco::format((fmt), (arg1)), __FILE__, __LINE__); \
-	POCO_AMBIGUOUS_ELSE_BLOCKER_END
-
-#define poco_error_f2(logger, fmt, arg1, arg2) \
-	POCO_AMBIGUOUS_ELSE_BLOCKER_BEG \
-	if ((logger).error()) (logger).error(Poco::format((fmt), (arg1), (arg2)), __FILE__, __LINE__); \
-	POCO_AMBIGUOUS_ELSE_BLOCKER_END
-
-#define poco_error_f3(logger, fmt, arg1, arg2, arg3) \
-	POCO_AMBIGUOUS_ELSE_BLOCKER_BEG \
-	if ((logger).error()) (logger).error(Poco::format((fmt), (arg1), (arg2), (arg3)), __FILE__, __LINE__); \
-	POCO_AMBIGUOUS_ELSE_BLOCKER_END
-
-#define poco_error_f4(logger, fmt, arg1, arg2, arg3, arg4) \
-	POCO_AMBIGUOUS_ELSE_BLOCKER_BEG \
-	if ((logger).error()) (logger).error(Poco::format((fmt), (arg1), (arg2), (arg3), (arg4)), __FILE__, __LINE__); \
-	POCO_AMBIGUOUS_ELSE_BLOCKER_END
-
 #define poco_error_f(logger, fmt, ...) \
 	POCO_AMBIGUOUS_ELSE_BLOCKER_BEG \
 	if ((logger).error()) (logger).error(Poco::format((fmt), __VA_ARGS__), __FILE__, __LINE__); \
 	POCO_AMBIGUOUS_ELSE_BLOCKER_END
 
+// Deprecated: use poco_error_f instead
+#define poco_error_f1(logger, fmt, arg1) \
+	poco_error_f(logger, fmt, arg1)
+#define poco_error_f2(logger, fmt, arg1, arg2) \
+	poco_error_f(logger, fmt, arg1, arg2)
+#define poco_error_f3(logger, fmt, arg1, arg2, arg3) \
+	poco_error_f(logger, fmt, arg1, arg2, arg3)
+#define poco_error_f4(logger, fmt, arg1, arg2, arg3, arg4) \
+	poco_error_f(logger, fmt, arg1, arg2, arg3, arg4)
+
 #define poco_warning(logger, msg) \
 	POCO_AMBIGUOUS_ELSE_BLOCKER_BEG \
 	if ((logger).warning()) (logger).warning(msg, __FILE__, __LINE__); \
 	POCO_AMBIGUOUS_ELSE_BLOCKER_END
 
-#define poco_warning_f1(logger, fmt, arg1) \
-	POCO_AMBIGUOUS_ELSE_BLOCKER_BEG \
-	if ((logger).warning()) (logger).warning(Poco::format((fmt), (arg1)), __FILE__, __LINE__); \
-	POCO_AMBIGUOUS_ELSE_BLOCKER_END
-
-#define poco_warning_f2(logger, fmt, arg1, arg2) \
-	POCO_AMBIGUOUS_ELSE_BLOCKER_BEG \
-	if ((logger).warning()) (logger).warning(Poco::format((fmt), (arg1), (arg2)), __FILE__, __LINE__); \
-	POCO_AMBIGUOUS_ELSE_BLOCKER_END
-
-#define poco_warning_f3(logger, fmt, arg1, arg2, arg3) \
-	POCO_AMBIGUOUS_ELSE_BLOCKER_BEG \
-	if ((logger).warning()) (logger).warning(Poco::format((fmt), (arg1), (arg2), (arg3)), __FILE__, __LINE__); \
-	POCO_AMBIGUOUS_ELSE_BLOCKER_END
-
-#define poco_warning_f4(logger, fmt, arg1, arg2, arg3, arg4) \
-	POCO_AMBIGUOUS_ELSE_BLOCKER_BEG \
-	if ((logger).warning()) (logger).warning(Poco::format((fmt), (arg1), (arg2), (arg3), (arg4)), __FILE__, __LINE__); \
-	POCO_AMBIGUOUS_ELSE_BLOCKER_END
-
 #define poco_warning_f(logger, fmt, ...) \
 	POCO_AMBIGUOUS_ELSE_BLOCKER_BEG \
 	if ((logger).warning()) (logger).warning(Poco::format((fmt), __VA_ARGS__), __FILE__, __LINE__); \
 	POCO_AMBIGUOUS_ELSE_BLOCKER_END
 
+// Deprecated: use poco_warning_f instead
+#define poco_warning_f1(logger, fmt, arg1) \
+	poco_warning_f(logger, fmt, arg1)
+#define poco_warning_f2(logger, fmt, arg1, arg2) \
+	poco_warning_f(logger, fmt, arg1, arg2)
+#define poco_warning_f3(logger, fmt, arg1, arg2, arg3) \
+	poco_warning_f(logger, fmt, arg1, arg2, arg3)
+#define poco_warning_f4(logger, fmt, arg1, arg2, arg3, arg4) \
+	poco_warning_f(logger, fmt, arg1, arg2, arg3, arg4)
+
 #define poco_notice(logger, msg) \
 	POCO_AMBIGUOUS_ELSE_BLOCKER_BEG \
 	if ((logger).notice()) (logger).notice(msg, __FILE__, __LINE__); \
 	POCO_AMBIGUOUS_ELSE_BLOCKER_END
 
-#define poco_notice_f1(logger, fmt, arg1) \
-	POCO_AMBIGUOUS_ELSE_BLOCKER_BEG \
-	if ((logger).notice()) (logger).notice(Poco::format((fmt), (arg1)), __FILE__, __LINE__); \
-	POCO_AMBIGUOUS_ELSE_BLOCKER_END
-
-#define poco_notice_f2(logger, fmt, arg1, arg2) \
-	POCO_AMBIGUOUS_ELSE_BLOCKER_BEG \
-	if ((logger).notice()) (logger).notice(Poco::format((fmt), (arg1), (arg2)), __FILE__, __LINE__); \
-	POCO_AMBIGUOUS_ELSE_BLOCKER_END
-
-#define poco_notice_f3(logger, fmt, arg1, arg2, arg3) \
-	POCO_AMBIGUOUS_ELSE_BLOCKER_BEG \
-	if ((logger).notice()) (logger).notice(Poco::format((fmt), (arg1), (arg2), (arg3)), __FILE__, __LINE__); \
-	POCO_AMBIGUOUS_ELSE_BLOCKER_END
-
-#define poco_notice_f4(logger, fmt, arg1, arg2, arg3, arg4) \
-	POCO_AMBIGUOUS_ELSE_BLOCKER_BEG \
-	if ((logger).notice()) (logger).notice(Poco::format((fmt), (arg1), (arg2), (arg3), (arg4)), __FILE__, __LINE__); \
-	POCO_AMBIGUOUS_ELSE_BLOCKER_END
-
 #define poco_notice_f(logger, fmt, ...) \
 	POCO_AMBIGUOUS_ELSE_BLOCKER_BEG \
 	if ((logger).notice()) (logger).notice(Poco::format((fmt), __VA_ARGS__), __FILE__, __LINE__); \
 	POCO_AMBIGUOUS_ELSE_BLOCKER_END
 
+// Deprecated: use poco_notice_f instead
+#define poco_notice_f1(logger, fmt, arg1) \
+	poco_notice_f(logger, fmt, arg1)
+#define poco_notice_f2(logger, fmt, arg1, arg2) \
+	poco_notice_f(logger, fmt, arg1, arg2)
+#define poco_notice_f3(logger, fmt, arg1, arg2, arg3) \
+	poco_notice_f(logger, fmt, arg1, arg2, arg3)
+#define poco_notice_f4(logger, fmt, arg1, arg2, arg3, arg4) \
+	poco_notice_f(logger, fmt, arg1, arg2, arg3, arg4)
+
 #define poco_information(logger, msg) \
 	POCO_AMBIGUOUS_ELSE_BLOCKER_BEG \
 	if ((logger).information()) (logger).information(msg, __FILE__, __LINE__); \
 	POCO_AMBIGUOUS_ELSE_BLOCKER_END
 
-#define poco_information_f1(logger, fmt, arg1) \
-	POCO_AMBIGUOUS_ELSE_BLOCKER_BEG \
-	if ((logger).information()) (logger).information(Poco::format((fmt), (arg1)), __FILE__, __LINE__); \
-	POCO_AMBIGUOUS_ELSE_BLOCKER_END
-
-#define poco_information_f2(logger, fmt, arg1, arg2) \
-	POCO_AMBIGUOUS_ELSE_BLOCKER_BEG \
-	if ((logger).information()) (logger).information(Poco::format((fmt), (arg1), (arg2)), __FILE__, __LINE__); \
-	POCO_AMBIGUOUS_ELSE_BLOCKER_END
-
-#define poco_information_f3(logger, fmt, arg1, arg2, arg3) \
-	POCO_AMBIGUOUS_ELSE_BLOCKER_BEG \
-	if ((logger).information()) (logger).information(Poco::format((fmt), (arg1), (arg2), (arg3)), __FILE__, __LINE__); \
-	POCO_AMBIGUOUS_ELSE_BLOCKER_END
-
-#define poco_information_f4(logger, fmt, arg1, arg2, arg3, arg4) \
-	POCO_AMBIGUOUS_ELSE_BLOCKER_BEG \
-	if ((logger).information()) (logger).information(Poco::format((fmt), (arg1), (arg2), (arg3), (arg4)), __FILE__, __LINE__); \
-	POCO_AMBIGUOUS_ELSE_BLOCKER_END
-
 #define poco_information_f(logger, fmt, ...) \
 	POCO_AMBIGUOUS_ELSE_BLOCKER_BEG \
 	if ((logger).information()) (logger).information(Poco::format((fmt), __VA_ARGS__), __FILE__, __LINE__); \
 	POCO_AMBIGUOUS_ELSE_BLOCKER_END
 
+// Deprecated: use poco_information_f instead
+#define poco_information_f1(logger, fmt, arg1) \
+	poco_information_f(logger, fmt, arg1)
+#define poco_information_f2(logger, fmt, arg1, arg2) \
+	poco_information_f(logger, fmt, arg1, arg2)
+#define poco_information_f3(logger, fmt, arg1, arg2, arg3) \
+	poco_information_f(logger, fmt, arg1, arg2, arg3)
+#define poco_information_f4(logger, fmt, arg1, arg2, arg3, arg4) \
+	poco_information_f(logger, fmt, arg1, arg2, arg3, arg4)
+
 #if defined(_DEBUG) || defined(POCO_LOG_DEBUG)
 #define poco_debug(logger, msg) \
 		POCO_AMBIGUOUS_ELSE_BLOCKER_BEG \
 		if ((logger).debug()) (logger).debug(msg, __FILE__, __LINE__); \
 		POCO_AMBIGUOUS_ELSE_BLOCKER_END
 
-#define poco_debug_f1(logger, fmt, arg1) \
-		POCO_AMBIGUOUS_ELSE_BLOCKER_BEG \
-		if ((logger).debug()) (logger).debug(Poco::format((fmt), (arg1)), __FILE__, __LINE__); \
-		POCO_AMBIGUOUS_ELSE_BLOCKER_END
-
-#define poco_debug_f2(logger, fmt, arg1, arg2) \
-		POCO_AMBIGUOUS_ELSE_BLOCKER_BEG \
-		if ((logger).debug()) (logger).debug(Poco::format((fmt), (arg1), (arg2)), __FILE__, __LINE__); \
-		POCO_AMBIGUOUS_ELSE_BLOCKER_END
-
-#define poco_debug_f3(logger, fmt, arg1, arg2, arg3) \
-		POCO_AMBIGUOUS_ELSE_BLOCKER_BEG \
-		if ((logger).debug()) (logger).debug(Poco::format((fmt), (arg1), (arg2), (arg3)), __FILE__, __LINE__); \
-		POCO_AMBIGUOUS_ELSE_BLOCKER_END
-
-#define poco_debug_f4(logger, fmt, arg1, arg2, arg3, arg4) \
-		POCO_AMBIGUOUS_ELSE_BLOCKER_BEG \
-		if ((logger).debug()) (logger).debug(Poco::format((fmt), (arg1), (arg2), (arg3), (arg4)), __FILE__, __LINE__); \
-		POCO_AMBIGUOUS_ELSE_BLOCKER_END
-
 #define poco_debug_f(logger, fmt, ...) \
 		POCO_AMBIGUOUS_ELSE_BLOCKER_BEG \
 		if ((logger).debug()) (logger).debug(Poco::format((fmt), __VA_ARGS__), __FILE__, __LINE__); \
 		POCO_AMBIGUOUS_ELSE_BLOCKER_END
 
+// Deprecated: use poco_debug_f instead
+#define poco_debug_f1(logger, fmt, arg1) \
+		poco_debug_f(logger, fmt, arg1)
+#define poco_debug_f2(logger, fmt, arg1, arg2) \
+		poco_debug_f(logger, fmt, arg1, arg2)
+#define poco_debug_f3(logger, fmt, arg1, arg2, arg3) \
+		poco_debug_f(logger, fmt, arg1, arg2, arg3)
+#define poco_debug_f4(logger, fmt, arg1, arg2, arg3, arg4) \
+		poco_debug_f(logger, fmt, arg1, arg2, arg3, arg4)
+
 #define poco_trace(logger, msg) \
 		POCO_AMBIGUOUS_ELSE_BLOCKER_BEG \
 		if ((logger).trace()) (logger).trace(msg, __FILE__, __LINE__); \
 		POCO_AMBIGUOUS_ELSE_BLOCKER_END
 
-#define poco_trace_f1(logger, fmt, arg1) \
-		POCO_AMBIGUOUS_ELSE_BLOCKER_BEG \
-		if ((logger).trace()) (logger).trace(Poco::format((fmt), (arg1)), __FILE__, __LINE__); \
-		POCO_AMBIGUOUS_ELSE_BLOCKER_END
-
-#define poco_trace_f2(logger, fmt, arg1, arg2) \
-		POCO_AMBIGUOUS_ELSE_BLOCKER_BEG \
-		if ((logger).trace()) (logger).trace(Poco::format((fmt), (arg1), (arg2)), __FILE__, __LINE__); \
-		POCO_AMBIGUOUS_ELSE_BLOCKER_END
-
-#define poco_trace_f3(logger, fmt, arg1, arg2, arg3) \
-		POCO_AMBIGUOUS_ELSE_BLOCKER_BEG \
-		if ((logger).trace()) (logger).trace(Poco::format((fmt), (arg1), (arg2), (arg3)), __FILE__, __LINE__); \
-		POCO_AMBIGUOUS_ELSE_BLOCKER_END
-
-#define poco_trace_f4(logger, fmt, arg1, arg2, arg3, arg4) \
-		POCO_AMBIGUOUS_ELSE_BLOCKER_BEG \
-		if ((logger).trace()) (logger).trace(Poco::format((fmt), (arg1), (arg2), (arg3), (arg4)), __FILE__, __LINE__); \
-		POCO_AMBIGUOUS_ELSE_BLOCKER_END
-
 #define poco_trace_f(logger, fmt, ...) \
 		POCO_AMBIGUOUS_ELSE_BLOCKER_BEG \
 		if ((logger).trace()) (logger).trace(Poco::format((fmt), __VA_ARGS__), __FILE__, __LINE__); \
 		POCO_AMBIGUOUS_ELSE_BLOCKER_END
+
+// Deprecated: use poco_trace_f instead
+#define poco_trace_f1(logger, fmt, arg1) \
+		poco_trace_f(logger, fmt, arg1)
+#define poco_trace_f2(logger, fmt, arg1, arg2) \
+		poco_trace_f(logger, fmt, arg1, arg2)
+#define poco_trace_f3(logger, fmt, arg1, arg2, arg3) \
+		poco_trace_f(logger, fmt, arg1, arg2, arg3)
+#define poco_trace_f4(logger, fmt, arg1, arg2, arg3, arg4) \
+		poco_trace_f(logger, fmt, arg1, arg2, arg3, arg4)
 #else
 	#define poco_debug(logger, msg)
+	#define poco_debug_f(logger, fmt, ...)
+	// Deprecated: use poco_debug_f instead
 	#define poco_debug_f1(logger, fmt, arg1)
 	#define poco_debug_f2(logger, fmt, arg1, arg2)
 	#define poco_debug_f3(logger, fmt, arg1, arg2, arg3)
 	#define poco_debug_f4(logger, fmt, arg1, arg2, arg3, arg4)
-	#define poco_debug_f(logger, fmt, ...)
 	#define poco_trace(logger, msg)
+	#define poco_trace_f(logger, fmt, ...)
+	// Deprecated: use poco_trace_f instead
 	#define poco_trace_f1(logger, fmt, arg1)
 	#define poco_trace_f2(logger, fmt, arg1, arg2)
 	#define poco_trace_f3(logger, fmt, arg1, arg2, arg3)
 	#define poco_trace_f4(logger, fmt, arg1, arg2, arg3, arg4)
-	#define poco_trace_f(logger, fmt, ...)
 #endif
 
 
@@ -790,6 +724,15 @@ inline void Logger::log(const std::string& text, Message::Priority prio)
 }
 
 
+inline void Logger::log(std::string&& text, Message::Priority prio)
+{
+	if (_level >= prio && _pChannel)
+	{
+		_pChannel->log(Message(_name, std::move(text), prio));
+	}
+}
+
+
 inline void Logger::logNPC(const std::string& text, Message::Priority prio)
 {
 	if (_pChannel)
@@ -799,6 +742,15 @@ inline void Logger::logNPC(const std::string& text, Message::Priority prio)
 }
 
 
+inline void Logger::logNPC(std::string&& text, Message::Priority prio)
+{
+	if (_pChannel)
+	{
+		_pChannel->log(Message(_name, std::move(text), prio));
+	}
+}
+
+
 inline void Logger::log(const std::string& text, Message::Priority prio, const char* file, LineNumber line)
 {
 	if (_level >= prio && _pChannel)
@@ -808,6 +760,15 @@ inline void Logger::log(const std::string& text, Message::Priority prio, const c
 }
 
 
+inline void Logger::log(std::string&& text, Message::Priority prio, const char* file, LineNumber line)
+{
+	if (_level >= prio && _pChannel)
+	{
+		_pChannel->log(Message(_name, std::move(text), prio, file, line));
+	}
+}
+
+
 inline void Logger::logAlways(const std::string& text, Message::Priority prio)
 {
 	if (_pChannel)
@@ -817,6 +778,15 @@ inline void Logger::logAlways(const std::string& text, Message::Priority prio)
 }
 
 
+inline void Logger::logAlways(std::string&& text, Message::Priority prio)
+{
+	if (_pChannel)
+	{
+		_pChannel->log(Message(_name, std::move(text), prio));
+	}
+}
+
+
 inline void Logger::fatal(const std::string& msg)
 {
 	log(msg, Message::PRIO_FATAL);
