@@ -20,6 +20,8 @@
 
 #include "Poco/Foundation.h"
 #include "Poco/RefCountedObject.h"
+#include "Poco/IOLock.h"
+#include <atomic>
 
 
 namespace Poco {
@@ -30,10 +32,10 @@ class Foundation_API PipeImpl: public RefCountedObject
 	/// that do not support pipes.
 {
 public:
-	typedef int Handle;
+	using Handle = int;
 
 	PipeImpl();
-	~PipeImpl();
+	~PipeImpl() override;
 	int writeBytes(const void* buffer, int length);
 	int readBytes(void* buffer, int length);
 	Handle readHandle() const;
@@ -42,8 +44,10 @@ public:
 	void closeWrite();
 
 private:
-	int _readfd;
-	int _writefd;
+	std::atomic<int> _readfd{-1};
+	std::atomic<int> _writefd{-1};
+	IOLock _readLock;
+	IOLock _writeLock;
 };
 
 
