@@ -49,7 +49,7 @@ public:
 		/// Default constructor creates an unmapped SharedMemory object.
 		/// No clients can connect to an unmapped SharedMemory object.
 
-	SharedMemory(const std::string& name, std::size_t size, AccessMode mode, const void* addrHint = 0, bool server = true);
+	SharedMemory(const std::string& name, std::size_t size, AccessMode mode, const void* addrHint = nullptr, bool server = true);
 		/// Creates or connects to a shared memory object with the given name.
 		///
 		/// For maximum portability, name should be a valid Unix filename and not
@@ -64,7 +64,7 @@ public:
 		/// by calling shm_unlink() (on POSIX platforms) when the SharedMemory object is destroyed.
 		/// The server parameter is ignored on Windows platforms.
 
-	SharedMemory(const File& file, AccessMode mode, const void* addrHint = 0);
+	SharedMemory(const File& file, AccessMode mode, const void* addrHint = nullptr);
 		/// Maps the entire contents of file into a shared memory segment.
 		///
 		/// An address hint can be passed to the system, specifying the desired
@@ -86,11 +86,11 @@ public:
 
 	char* begin() const;
 		/// Returns the start address of the shared memory segment.
-		/// Will be NULL for illegal segments.
+		/// Will be nullptr for illegal segments.
 
 	char* end() const;
 		/// Returns the one-past-end end address of the shared memory segment.
-		/// Will be NULL for illegal segments.
+		/// Will be nullptr for illegal segments.
 
 private:
 	SharedMemoryImpl* _pImpl;
